@@ -14,16 +14,20 @@ class TrailEdge(Edge):
     """
     def __init__(self, u, v, length, plane=None):
         super(TrailEdge, self).__init__(u, v)
-        self.attributes = {"length": length, "type": "trail", "plane": plane}
         # TODO
         # self.attributes = {"length": length, "state": state, type": "trail", "plane": plane}
+        self.attributes = {"length": length, "type": "trail", "plane": plane}
 
     def __repr__(self):
         """
         """
-        st = "{}(length={}, plane={})"
+        st = "{0}(length={1!r}, plane={2!r})"
         return st.format(self.__class__.__name__, self.attributes["length"], self.attributes["plane"])
 
+# ==============================================================================
+# Main
+# ==============================================================================
+
 
 if __name__ == "__main__":
     pass
