@@ -9,4 +9,4 @@ from compas_cem.elements import DeviationEdge
 class DeviationEdgeComponent(component):
     def RunScript(self, line, force):
         if line and force is not None:
-            return DeviationEdge.from_rhino_line(line, force)
+            return DeviationEdge.from_rhino_line(line, force=force)
