@@ -14,8 +14,8 @@ Optimizers
     Optimizer
     solve_nlopt_proxy
 
-Constraints
-===========
+Optimization Constraints
+========================
 
 .. autosummary::
     :toctree: generated/
@@ -40,17 +40,6 @@ Optimization Parameters
     OriginNodeXParameter
     OriginNodeYParameter
     OriginNodeZParameter
-
-NLOpt
-=====
-.. autosummary::
-    :toctree: generated/
-    :nosignatures:
-
-    nlopt_algorithm
-    nlopt_algorithms
-    nlopt_solver
-
 """
 
 from __future__ import absolute_import
